@@ -15,6 +15,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
+ * The Totem project hereby grant permission for non-gpl compatible GStreamer
+ * plugins to be used and distributed together with GStreamer and Totem. This
+ * permission are above and beyond the permissions granted by the GPL license
+ * Totem is covered by.
+ *
+ * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * See license_change file for details.
+ *
  */
 
 #ifndef __TOTEM_PRIVATE_H__
@@ -25,7 +33,7 @@
 #include <libgnomevfs/gnome-vfs.h>
 
 #include "totem-remote.h"
-#include "scrsaver.h"
+#include "totem-scrsaver.h"
 #include "egg-recent-model.h"
 #include "egg-recent-view-gtk.h"
 #include "totem-playlist.h"
@@ -48,6 +56,7 @@ typedef enum {
 struct Totem {
 	/* Control window */
 	GladeXML *xml;
+	GladeXML *xml_popup;
 	GtkWidget *win;
 	BaconVideoWidget *bvw;
 	GtkWidget *prefs;
